from latex_input.unicode_structs import (
    CharacterFontVariant, FontVariantType,
)

from latex_input.cached_unicode_data import (
    cached_character_font_variants as character_font_variants,
    cached_subscripts as subscript_mapping,
    cached_superscripts as superscript_mapping
)

# Manual fixes
superscript_mapping["α"] = "ᵅ"
superscript_mapping["ϵ"] = "ᵋ"
superscript_mapping["ι"] = "ᶥ"
superscript_mapping["ϕ"] = "ᶲ"

# Planck's constant already fulfills this role, but isn't detected
character_font_variants["h"].append(
    CharacterFontVariant(
        text="\u210E",
        kind=FontVariantType.ITALIC | FontVariantType.MATHEMATICAL
    )
)

# Imported from https://github.com/kmgb/LaTeX-Unicode-Map/blob/main/output/symbols.txt
# Using regex \s+(.+)=([\s\S])$ -> "$1": "$2",
latex_symbols: dict[str, str] = {
    "mathexclam": "!",
    "mathoctothorpe": "#",
    "mathdollar": "$",
    "mathpercent": "%",
    "mathampersand": "&",
    "lparen": "(",
    "rparen": ")",
    "mathplus": "+",
    "mathcomma": ",",
    "mathperiod": ".",
    "mathslash": "/",
    "mathcolon": ":",
    "mathsemicolon": ";",
    "less": "<",
    "equal": "=",
    "greater": ">",
    "mathquestion": "?",
    "mathatsign": "@",
    "lbrack": "[",
    "backslash": "\\",
    "rbrack": "]",
    "lbrace": "{",
    "vert": "|",
    "rbrace": "}",
    "mathsterling": "£",
    "mathyen": "¥",
    "mathsection": "§",
    "neg": "¬",
    "pm": "±",
    "mathparagraph": "¶",
    "cdotp": "·",
    "times": "×",
    "matheth": "ð",
    "div": "÷",
    "Zbar": "Ƶ",
    "grave": "̀",
    "acute": "́",
    "hat": "̂",
    "widehat": "̂",
    "tilde": "̃",
    "widetilde": "̃",
    "bar": "̄",
    "overbar": "̅",
    "wideoverbar": "̅",
    "breve": "̆",
    "widebreve": "̆",
    "dot": "̇",
    "ddot": "̈",
    "ovhook": "̉",
    "ocirc": "̊",
    "check": "̌",
    "widecheck": "̌",
    "candra": "̐",
    "oturnedcomma": "̒",
    "ocommatopright": "̕",
    "droang": "̚",
    "wideutilde": "̰",
    "mathunderbar": "̲",
    "notaccent": "̸",
    "underleftrightarrow": "͍",
    "mupAlpha": "Α",
    "mupBeta": "Β",
    "mupGamma": "Γ",
    "mupDelta": "Δ",
    "mupEpsilon": "Ε",
    "mupZeta": "Ζ",
    "mupEta": "Η",
    "mupTheta": "Θ",
    "mupIota": "Ι",
    "mupKappa": "Κ",
    "mupLambda": "Λ",
    "mupMu": "Μ",
    "mupNu": "Ν",
    "mupXi": "Ξ",
    "mupOmicron": "Ο",
    "mupPi": "Π",
    "mupRho": "Ρ",
    "mupSigma": "Σ",
    "mupTau": "Τ",
    "mupUpsilon": "Υ",
    "mupPhi": "Φ",
    "mupChi": "Χ",
    "mupPsi": "Ψ",
    "mupOmega": "Ω",
    "mupalpha": "α",
    "mupbeta": "β",
    "mupgamma": "γ",
    "mupdelta": "δ",
    "mupvarepsilon": "ε",
    "mupzeta": "ζ",
    "mupeta": "η",
    "muptheta": "θ",
    "mupiota": "ι",
    "mupkappa": "κ",
    "muplambda": "λ",
    "mupmu": "μ",
    "mupnu": "ν",
    "mupxi": "ξ",
    "mupomicron": "ο",
    "muppi": "π",
    "muprho": "ρ",
    "mupvarsigma": "ς",
    "mupsigma": "σ",
    "muptau": "τ",
    "mupupsilon": "υ",
    "mupvarphi": "φ",
    "mupchi": "χ",
    "muppsi": "ψ",
    "mupomega": "ω",
    "mupvartheta": "ϑ",
    "mupphi": "ϕ",
    "mupvarpi": "ϖ",
    "upDigamma": "Ϝ",
    "updigamma": "ϝ",
    "mupvarkappa": "ϰ",
    "mupvarrho": "ϱ",
    "mupvarTheta": "ϴ",
    "mupepsilon": "ϵ",
    "upbackepsilon": "϶",
    "mathhyphen": "‐",
    "horizbar": "―",
    "Vert": "‖",
    "twolowline": "‗",
    "dagger": "†",
    "ddagger": "‡",
    "smblkcircle": "•",
    "enleadertwodots": "‥",
    "unicodeellipsis": "…",
    "prime": "′",
    "dprime": "″",
    "trprime": "‴",
    "backprime": "‵",
    "backdprime": "‶",
    "backtrprime": "‷",
    "caretinsert": "‸",
    "Exclam": "‼",
    "tieconcat": "⁀",
    "hyphenbullet": "⁃",
    "fracslash": "⁄",
    "Question": "⁇",
    "closure": "⁐",
    "qprime": "⁗",
    "euro": "€",
    "leftharpoonaccent": "⃐",
    "overleftharpoon": "⃐",
    "rightharpoonaccent": "⃑",
    "overrightharpoon": "⃑",
    "vertoverlay": "⃒",
    "overleftarrow": "⃖",
    "overrightarrow": "⃗",
    "vec": "⃗",
    "dddot": "⃛",
    "ddddot": "⃜",
    "enclosecircle": "⃝",
    "enclosesquare": "⃞",
    "enclosediamond": "⃟",
    "overleftrightarrow": "⃡",
    "enclosetriangle": "⃤",
    "annuity": "⃧",
    "threeunderdot": "⃨",
    "widebridgeabove": "⃩",
    "underrightharpoondown": "⃬",
    "underleftharpoondown": "⃭",
    "underleftarrow": "⃮",
    "underrightarrow": "⃯",
    "asteraccent": "⃰",
    "BbbC": "ℂ",
    "Eulerconst": "ℇ",
    "mscrg": "ℊ",
    "mscrH": "ℋ",
    "mfrakH": "ℌ",
    "BbbH": "ℍ",
    "Planckconst": "ℎ",
    "hslash": "ℏ",
    "mscrI": "ℐ",
    "Im": "ℑ",
    "mscrL": "ℒ",
    "ell": "ℓ",
    "BbbN": "ℕ",
    "wp": "℘",
    "BbbP": "ℙ",
    "BbbQ": "ℚ",
    "mscrR": "ℛ",
    "Re": "ℜ",
    "BbbR": "ℝ",
    "BbbZ": "ℤ",
    "mho": "℧",
    "mfrakZ": "ℨ",
    "turnediota": "℩",
    "Angstrom": "Å",
    "mscrB": "ℬ",
    "mfrakC": "ℭ",
    "mscre": "ℯ",
    "mscrE": "ℰ",
    "mscrF": "ℱ",
    "Finv": "Ⅎ",
    "mscrM": "ℳ",
    "mscro": "ℴ",
    "aleph": "ℵ",
    "beth": "ℶ",
    "gimel": "ℷ",
    "daleth": "ℸ",
    "Bbbpi": "ℼ",
    "Bbbgamma": "ℽ",
    "BbbGamma": "ℾ",
    "BbbPi": "ℿ",
    "Bbbsum": "⅀",
    "Game": "⅁",
    "sansLturned": "⅂",
    "sansLmirrored": "⅃",
    "Yup": "⅄",
    "mitBbbD": "ⅅ",
    "mitBbbd": "ⅆ",
    "mitBbbe": "ⅇ",
    "mitBbbi": "ⅈ",
    "mitBbbj": "ⅉ",
    "PropertyLine": "⅊",
    "upand": "⅋",
    "leftarrow": "←",
    "uparrow": "↑",
    "rightarrow": "→",
    "downarrow": "↓",
    "leftrightarrow": "↔",
    "updownarrow": "↕",
    "nwarrow": "↖",
    "nearrow": "↗",
    "searrow": "↘",
    "swarrow": "↙",
    "nleftarrow": "↚",
    "nrightarrow": "↛",
    "leftwavearrow": "↜",
    "rightwavearrow": "↝",
    "twoheadleftarrow": "↞",
    "twoheaduparrow": "↟",
    "twoheadrightarrow": "↠",
    "twoheaddownarrow": "↡",
    "leftarrowtail": "↢",
    "rightarrowtail": "↣",
    "mapsfrom": "↤",
    "mapsup": "↥",
    "mapsto": "↦",
    "mapsdown": "↧",
    "updownarrowbar": "↨",
    "hookleftarrow": "↩",
    "hookrightarrow": "↪",
    "looparrowleft": "↫",
    "looparrowright": "↬",
    "leftrightsquigarrow": "↭",
    "nleftrightarrow": "↮",
    "downzigzagarrow": "↯",
    "Lsh": "↰",
    "Rsh": "↱",
    "Ldsh": "↲",
    "Rdsh": "↳",
    "linefeed": "↴",
    "carriagereturn": "↵",
    "curvearrowleft": "↶",
    "curvearrowright": "↷",
    "barovernorthwestarrow": "↸",
    "barleftarrowrightarrowbar": "↹",
    "acwopencirclearrow": "↺",
    "cwopencirclearrow": "↻",
    "leftharpoonup": "↼",
    "leftharpoondown": "↽",
    "upharpoonright": "↾",
    "upharpoonleft": "↿",
    "rightharpoonup": "⇀",
    "rightharpoondown": "⇁",
    "downharpoonright": "⇂",
    "downharpoonleft": "⇃",
    "rightleftarrows": "⇄",
    "updownarrows": "⇅",
    "leftrightarrows": "⇆",
    "leftleftarrows": "⇇",
    "upuparrows": "⇈",
    "rightrightarrows": "⇉",
    "downdownarrows": "⇊",
    "leftrightharpoons": "⇋",
    "rightleftharpoons": "⇌",
    "nLeftarrow": "⇍",
    "nLeftrightarrow": "⇎",
    "nRightarrow": "⇏",
    "Leftarrow": "⇐",
    "Uparrow": "⇑",
    "Rightarrow": "⇒",
    "Downarrow": "⇓",
    "Leftrightarrow": "⇔",
    "Updownarrow": "⇕",
    "Nwarrow": "⇖",
    "Nearrow": "⇗",
    "Searrow": "⇘",
    "Swarrow": "⇙",
    "Lleftarrow": "⇚",
    "Rrightarrow": "⇛",
    "leftsquigarrow": "⇜",
    "rightsquigarrow": "⇝",
    "nHuparrow": "⇞",
    "nHdownarrow": "⇟",
    "leftdasharrow": "⇠",
    "updasharrow": "⇡",
    "rightdasharrow": "⇢",
    "downdasharrow": "⇣",
    "barleftarrow": "⇤",
    "rightarrowbar": "⇥",
    "leftwhitearrow": "⇦",
    "upwhitearrow": "⇧",
    "rightwhitearrow": "⇨",
    "downwhitearrow": "⇩",
    "whitearrowupfrombar": "⇪",
    "circleonrightarrow": "⇴",
    "downuparrows": "⇵",
    "rightthreearrows": "⇶",
    "nvleftarrow": "⇷",
    "nvrightarrow": "⇸",
    "nvleftrightarrow": "⇹",
    "nVleftarrow": "⇺",
    "nVrightarrow": "⇻",
    "nVleftrightarrow": "⇼",
    "leftarrowtriangle": "⇽",
    "rightarrowtriangle": "⇾",
    "leftrightarrowtriangle": "⇿",
    "forall": "∀",
    "complement": "∁",
    "partial": "∂",
    "exists": "∃",
    "nexists": "∄",
    "varnothing": "∅",
    "increment": "∆",
    "nabla": "∇",
    "in": "∈",
    "notin": "∉",
    "smallin": "∊",
    "ni": "∋",
    "nni": "∌",
    "smallni": "∍",
    "QED": "∎",
    "prod": "∏",
    "coprod": "∐",
    "sum": "∑",
    "minus": "−",
    "mp": "∓",
    "dotplus": "∔",
    "divslash": "∕",
    "smallsetminus": "∖",
    "ast": "∗",
    "vysmwhtcircle": "∘",
    "vysmblkcircle": "∙",
    "sqrt": "√",
    "surd": "√",
    "cuberoot": "∛",
    "fourthroot": "∜",
    "propto": "∝",
    "infty": "∞",
    "rightangle": "∟",
    "angle": "∠",
    "measuredangle": "∡",
    "sphericalangle": "∢",
    "mid": "∣",
    "nmid": "∤",
    "parallel": "∥",
    "nparallel": "∦",
    "wedge": "∧",
    "vee": "∨",
    "cap": "∩",
    "cup": "∪",
    "int": "∫",
    "iint": "∬",
    "iiint": "∭",
    "oint": "∮",
    "oiint": "∯",
    "oiiint": "∰",
    "intclockwise": "∱",
    "varointclockwise": "∲",
    "ointctrclockwise": "∳",
    "therefore": "∴",
    "because": "∵",
    "mathratio": "∶",
    "Colon": "∷",
    "dotminus": "∸",
    "dashcolon": "∹",
    "dotsminusdots": "∺",
    "kernelcontraction": "∻",
    "sim": "∼",
    "backsim": "∽",
    "invlazys": "∾",
    "sinewave": "∿",
    "wr": "≀",
    "nsim": "≁",
    "eqsim": "≂",
    "simeq": "≃",
    "nsime": "≄",
    "sime": "≃",
    "nsimeq": "≄",
    "cong": "≅",
    "simneqq": "≆",
    "ncong": "≇",
    "approx": "≈",
    "napprox": "≉",
    "approxeq": "≊",
    "approxident": "≋",
    "backcong": "≌",
    "asymp": "≍",
    "Bumpeq": "≎",
    "bumpeq": "≏",
    "doteq": "≐",
    "Doteq": "≑",
    "fallingdotseq": "≒",
    "risingdotseq": "≓",
    "coloneq": "≔",
    "eqcolon": "≕",
    "eqcirc": "≖",
    "circeq": "≗",
    "arceq": "≘",
    "wedgeq": "≙",
    "veeeq": "≚",
    "stareq": "≛",
    "triangleq": "≜",
    "eqdef": "≝",
    "measeq": "≞",
    "questeq": "≟",
    "ne": "≠",
    "equiv": "≡",
    "nequiv": "≢",
    "Equiv": "≣",
    "leq": "≤",
    "geq": "≥",
    "leqq": "≦",
    "geqq": "≧",
    "lneqq": "≨",
    "gneqq": "≩",
    "ll": "≪",
    "gg": "≫",
    "between": "≬",
    "nasymp": "≭",
    "nless": "≮",
    "ngtr": "≯",
    "nleq": "≰",
    "ngeq": "≱",
    "lesssim": "≲",
    "gtrsim": "≳",
    "nlesssim": "≴",
    "ngtrsim": "≵",
    "lessgtr": "≶",
    "gtrless": "≷",
    "nlessgtr": "≸",
    "ngtrless": "≹",
    "prec": "≺",
    "succ": "≻",
    "preccurlyeq": "≼",
    "succcurlyeq": "≽",
    "precsim": "≾",
    "succsim": "≿",
    "nprec": "⊀",
    "nsucc": "⊁",
    "subset": "⊂",
    "supset": "⊃",
    "nsubset": "⊄",
    "nsupset": "⊅",
    "subseteq": "⊆",
    "supseteq": "⊇",
    "nsubseteq": "⊈",
    "nsupseteq": "⊉",
    "subsetneq": "⊊",
    "supsetneq": "⊋",
    "cupleftarrow": "⊌",
    "cupdot": "⊍",
    "uplus": "⊎",
    "sqsubset": "⊏",
    "sqsupset": "⊐",
    "sqsubseteq": "⊑",
    "sqsupseteq": "⊒",
    "sqcap": "⊓",
    "sqcup": "⊔",
    "oplus": "⊕",
    "ominus": "⊖",
    "otimes": "⊗",
    "oslash": "⊘",
    "odot": "⊙",
    "circledcirc": "⊚",
    "circledast": "⊛",
    "circledequal": "⊜",
    "circleddash": "⊝",
    "boxplus": "⊞",
    "boxminus": "⊟",
    "boxtimes": "⊠",
    "boxdot": "⊡",
    "vdash": "⊢",
    "dashv": "⊣",
    "top": "⊤",
    "bot": "⊥",
    "assert": "⊦",
    "models": "⊧",
    "vDash": "⊨",
    "Vdash": "⊩",
    "Vvdash": "⊪",
    "VDash": "⊫",
    "nvdash": "⊬",
    "nvDash": "⊭",
    "nVdash": "⊮",
    "nVDash": "⊯",
    "prurel": "⊰",
    "scurel": "⊱",
    "vartriangleleft": "⊲",
    "vartriangleright": "⊳",
    "trianglelefteq": "⊴",
    "trianglerighteq": "⊵",
    "origof": "⊶",
    "imageof": "⊷",
    "multimap": "⊸",
    "hermitmatrix": "⊹",
    "intercal": "⊺",
    "veebar": "⊻",
    "barwedge": "⊼",
    "barvee": "⊽",
    "measuredrightangle": "⊾",
    "varlrtriangle": "⊿",
    "bigwedge": "⋀",
    "bigvee": "⋁",
    "bigcap": "⋂",
    "bigcup": "⋃",
    "smwhtdiamond": "⋄",
    "cdot": "⋅",
    "star": "⋆",
    "divideontimes": "⋇",
    "bowtie": "⋈",
    "ltimes": "⋉",
    "rtimes": "⋊",
    "leftthreetimes": "⋋",
    "rightthreetimes": "⋌",
    "backsimeq": "⋍",
    "curlyvee": "⋎",
    "curlywedge": "⋏",
    "Subset": "⋐",
    "Supset": "⋑",
    "Cap": "⋒",
    "Cup": "⋓",
    "pitchfork": "⋔",
    "equalparallel": "⋕",
    "lessdot": "⋖",
    "gtrdot": "⋗",
    "lll": "⋘",
    "ggg": "⋙",
    "lesseqgtr": "⋚",
    "gtreqless": "⋛",
    "eqless": "⋜",
    "eqgtr": "⋝",
    "curlyeqprec": "⋞",
    "curlyeqsucc": "⋟",
    "npreccurlyeq": "⋠",
    "nsucccurlyeq": "⋡",
    "nsqsubseteq": "⋢",
    "nsqsupseteq": "⋣",
    "sqsubsetneq": "⋤",
    "sqsupsetneq": "⋥",
    "lnsim": "⋦",
    "gnsim": "⋧",
    "precnsim": "⋨",
    "succnsim": "⋩",
    "nvartriangleleft": "⋪",
    "nvartriangleright": "⋫",
    "ntrianglelefteq": "⋬",
    "ntrianglerighteq": "⋭",
    "vdots": "⋮",
    "unicodecdots": "⋯",
    "adots": "⋰",
    "ddots": "⋱",
    "disin": "⋲",
    "varisins": "⋳",
    "isins": "⋴",
    "isindot": "⋵",
    "varisinobar": "⋶",
    "isinobar": "⋷",
    "isinvb": "⋸",
    "isinE": "⋹",
    "nisd": "⋺",
    "varnis": "⋻",
    "nis": "⋼",
    "varniobar": "⋽",
    "niobar": "⋾",
    "bagmember": "⋿",
    "diameter": "⌀",
    "house": "⌂",
    "varbarwedge": "⌅",
    "vardoublebarwedge": "⌆",
    "lceil": "⌈",
    "rceil": "⌉",
    "lfloor": "⌊",
    "rfloor": "⌋",
    "invnot": "⌐",
    "sqlozenge": "⌑",
    "profline": "⌒",
    "profsurf": "⌓",
    "viewdata": "⌗",
    "turnednot": "⌙",
    "ulcorner": "⌜",
    "urcorner": "⌝",
    "llcorner": "⌞",
    "lrcorner": "⌟",
    "inttop": "⌠",
    "intbottom": "⌡",
    "frown": "⌢",
    "smile": "⌣",
    "varhexagonlrbonds": "⌬",
    "conictaper": "⌲",
    "topbot": "⌶",
    "obar": "⌽",
    "APLnotslash": "⌿",
    "APLnotbackslash": "⍀",
    "APLboxupcaret": "⍓",
    "APLboxquestion": "⍰",
    "rangledownzigzagarrow": "⍼",
    "hexagon": "⎔",
    "lparenuend": "⎛",
    "lparenextender": "⎜",
    "lparenlend": "⎝",
    "rparenuend": "⎞",
    "rparenextender": "⎟",
    "rparenlend": "⎠",
    "lbrackuend": "⎡",
    "lbrackextender": "⎢",
    "lbracklend": "⎣",
    "rbrackuend": "⎤",
    "rbrackextender": "⎥",
    "rbracklend": "⎦",
    "lbraceuend": "⎧",
    "lbracemid": "⎨",
    "lbracelend": "⎩",
    "vbraceextender": "⎪",
    "rbraceuend": "⎫",
    "rbracemid": "⎬",
    "rbracelend": "⎭",
    "intextender": "⎮",
    "harrowextender": "⎯",
    "lmoustache": "⎰",
    "rmoustache": "⎱",
    "sumtop": "⎲",
    "sumbottom": "⎳",
    "overbracket": "⎴",
    "underbracket": "⎵",
    "bbrktbrk": "⎶",
    "sqrtbottom": "⎷",
    "lvboxline": "⎸",
    "rvboxline": "⎹",
    "varcarriagereturn": "⏎",
    "overparen": "⏜",
    "underparen": "⏝",
    "overbrace": "⏞",
    "underbrace": "⏟",
    "obrbrak": "⏠",
    "ubrbrak": "⏡",
    "trapezium": "⏢",
    "benzenr": "⏣",
    "strns": "⏤",
    "fltns": "⏥",
    "accurrent": "⏦",
    "elinters": "⏧",
    "blanksymbol": "␢",
    "mathvisiblespace": "␣",
    "bdtriplevdash": "┆",
    "blockuphalf": "▀",
    "blocklowhalf": "▄",
    "blockfull": "█",
    "blocklefthalf": "▌",
    "blockrighthalf": "▐",
    "blockqtrshaded": "░",
    "blockhalfshaded": "▒",
    "blockthreeqtrshaded": "▓",
    "mdlgblksquare": "■",
    "mdlgwhtsquare": "□",
    "squoval": "▢",
    "blackinwhitesquare": "▣",
    "squarehfill": "▤",
    "squarevfill": "▥",
    "squarehvfill": "▦",
    "squarenwsefill": "▧",
    "squareneswfill": "▨",
    "squarecrossfill": "▩",
    "smblksquare": "▪",
    "smwhtsquare": "▫",
    "hrectangleblack": "▬",
    "hrectangle": "▭",
    "vrectangleblack": "▮",
    "vrectangle": "▯",
    "parallelogramblack": "▰",
    "parallelogram": "▱",
    "bigblacktriangleup": "▲",
    "bigtriangleup": "△",
    "blacktriangle": "▴",
    "vartriangle": "▵",
    "blacktriangleright": "▶",
    "triangleright": "▷",
    "smallblacktriangleright": "▸",
    "smalltriangleright": "▹",
    "blackpointerright": "►",
    "whitepointerright": "▻",
    "bigblacktriangledown": "▼",
    "bigtriangledown": "▽",
    "blacktriangledown": "▾",
    "triangledown": "▿",
    "blacktriangleleft": "◀",
    "triangleleft": "◁",
    "smallblacktriangleleft": "◂",
    "smalltriangleleft": "◃",
    "blackpointerleft": "◄",
    "whitepointerleft": "◅",
    "mdlgblkdiamond": "◆",
    "mdlgwhtdiamond": "◇",
    "blackinwhitediamond": "◈",
    "fisheye": "◉",
    "mdlgwhtlozenge": "◊",
    "mdlgwhtcircle": "○",
    "dottedcircle": "◌",
    "circlevertfill": "◍",
    "bullseye": "◎",
    "mdlgblkcircle": "●",
    "circlelefthalfblack": "◐",
    "circlerighthalfblack": "◑",
    "circlebottomhalfblack": "◒",
    "circletophalfblack": "◓",
    "circleurquadblack": "◔",
    "blackcircleulquadwhite": "◕",
    "blacklefthalfcircle": "◖",
    "blackrighthalfcircle": "◗",
    "inversebullet": "◘",
    "inversewhitecircle": "◙",
    "invwhiteupperhalfcircle": "◚",
    "invwhitelowerhalfcircle": "◛",
    "ularc": "◜",
    "urarc": "◝",
    "lrarc": "◞",
    "llarc": "◟",
    "topsemicircle": "◠",
    "botsemicircle": "◡",
    "lrblacktriangle": "◢",
    "llblacktriangle": "◣",
    "ulblacktriangle": "◤",
    "urblacktriangle": "◥",
    "smwhtcircle": "◦",
    "squareleftblack": "◧",
    "squarerightblack": "◨",
    "squareulblack": "◩",
    "squarelrblack": "◪",
    "boxbar": "◫",
    "trianglecdot": "◬",
    "triangleleftblack": "◭",
    "trianglerightblack": "◮",
    "lgwhtcircle": "◯",
    "squareulquad": "◰",
    "squarellquad": "◱",
    "squarelrquad": "◲",
    "squareurquad": "◳",
    "circleulquad": "◴",
    "circlellquad": "◵",
    "circlelrquad": "◶",
    "circleurquad": "◷",
    "ultriangle": "◸",
    "urtriangle": "◹",
    "lltriangle": "◺",
    "mdwhtsquare": "◻",
    "mdblksquare": "◼",
    "mdsmwhtsquare": "◽",
    "mdsmblksquare": "◾",
    "lrtriangle": "◿",
    "bigstar": "★",
    "bigwhitestar": "☆",
    "astrosun": "☉",
    "danger": "☡",
    "blacksmiley": "☻",
    "sun": "☼",
    "rightmoon": "☽",
    "leftmoon": "☾",
    "female": "♀",
    "male": "♂",
    "spadesuit": "♠",
    "heartsuit": "♡",
    "diamondsuit": "♢",
    "clubsuit": "♣",
    "varspadesuit": "♤",
    "varheartsuit": "♥",
    "vardiamondsuit": "♦",
    "varclubsuit": "♧",
    "quarternote": "♩",
    "eighthnote": "♪",
    "twonotes": "♫",
    "flat": "♭",
    "natural": "♮",
    "sharp": "♯",
    "acidfree": "♾",
    "dicei": "⚀",
    "diceii": "⚁",
    "diceiii": "⚂",
    "diceiv": "⚃",
    "dicev": "⚄",
    "dicevi": "⚅",
    "circledrightdot": "⚆",
    "circledtwodots": "⚇",
    "blackcircledrightdot": "⚈",
    "blackcircledtwodots": "⚉",
    "Hermaphrodite": "⚥",
    "mdwhtcircle": "⚪",
    "mdblkcircle": "⚫",
    "mdsmwhtcircle": "⚬",
    "neuter": "⚲",
    "checkmark": "✓",
    "maltese": "✠",
    "circledstar": "✪",
    "varstar": "✶",
    "dingasterisk": "✽",
    "lbrbrak": "❲",
    "rbrbrak": "❳",
    "draftingarrow": "➛",
    "threedangle": "⟀",
    "whiteinwhitetriangle": "⟁",
    "perp": "⟂",
    "subsetcirc": "⟃",
    "supsetcirc": "⟄",
    "lbag": "⟅",
    "rbag": "⟆",
    "veedot": "⟇",
    "bsolhsub": "⟈",
    "suphsol": "⟉",
    "longdivision": "⟌",
    "diamondcdot": "⟐",
    "wedgedot": "⟑",
    "upin": "⟒",
    "pullback": "⟓",
    "pushout": "⟔",
    "leftouterjoin": "⟕",
    "rightouterjoin": "⟖",
    "fullouterjoin": "⟗",
    "bigbot": "⟘",
    "bigtop": "⟙",
    "DashVDash": "⟚",
    "dashVdash": "⟛",
    "multimapinv": "⟜",
    "vlongdash": "⟝",
    "longdashv": "⟞",
    "cirbot": "⟟",
    "lozengeminus": "⟠",
    "concavediamond": "⟡",
    "concavediamondtickleft": "⟢",
    "concavediamondtickright": "⟣",
    "whitesquaretickleft": "⟤",
    "whitesquaretickright": "⟥",
    "lBrack": "⟦",
    "rBrack": "⟧",
    "langle": "⟨",
    "rangle": "⟩",
    "lAngle": "⟪",
    "rAngle": "⟫",
    "Lbrbrak": "⟬",
    "Rbrbrak": "⟭",
    "lgroup": "⟮",
    "rgroup": "⟯",
    "UUparrow": "⟰",
    "DDownarrow": "⟱",
    "acwgapcirclearrow": "⟲",
    "cwgapcirclearrow": "⟳",
    "rightarrowonoplus": "⟴",
    "longleftarrow": "⟵",
    "longrightarrow": "⟶",
    "longleftrightarrow": "⟷",
    "Longleftarrow": "⟸",
    "Longrightarrow": "⟹",
    "Longleftrightarrow": "⟺",
    "longmapsfrom": "⟻",
    "longmapsto": "⟼",
    "Longmapsfrom": "⟽",
    "Longmapsto": "⟾",
    "longrightsquigarrow": "⟿",
    "nvtwoheadrightarrow": "⤀",
    "nVtwoheadrightarrow": "⤁",
    "nvLeftarrow": "⤂",
    "nvRightarrow": "⤃",
    "nvLeftrightarrow": "⤄",
    "twoheadmapsto": "⤅",
    "Mapsfrom": "⤆",
    "Mapsto": "⤇",
    "downarrowbarred": "⤈",
    "uparrowbarred": "⤉",
    "Uuparrow": "⤊",
    "Ddownarrow": "⤋",
    "leftbkarrow": "⤌",
    "rightbkarrow": "⤍",
    "leftdbkarrow": "⤎",
    "dbkarrow": "⤏",
    "drbkarrow": "⤐",
    "rightdotarrow": "⤑",
    "baruparrow": "⤒",
    "downarrowbar": "⤓",
    "nvrightarrowtail": "⤔",
    "nVrightarrowtail": "⤕",
    "twoheadrightarrowtail": "⤖",
    "nvtwoheadrightarrowtail": "⤗",
    "nVtwoheadrightarrowtail": "⤘",
    "lefttail": "⤙",
    "righttail": "⤚",
    "leftdbltail": "⤛",
    "rightdbltail": "⤜",
    "diamondleftarrow": "⤝",
    "rightarrowdiamond": "⤞",
    "diamondleftarrowbar": "⤟",
    "barrightarrowdiamond": "⤠",
    "nwsearrow": "⤡",
    "neswarrow": "⤢",
    "hknwarrow": "⤣",
    "hknearrow": "⤤",
    "hksearrow": "⤥",
    "hkswarrow": "⤦",
    "tona": "⤧",
    "toea": "⤨",
    "tosa": "⤩",
    "towa": "⤪",
    "rdiagovfdiag": "⤫",
    "fdiagovrdiag": "⤬",
    "seovnearrow": "⤭",
    "neovsearrow": "⤮",
    "fdiagovnearrow": "⤯",
    "rdiagovsearrow": "⤰",
    "neovnwarrow": "⤱",
    "nwovnearrow": "⤲",
    "rightcurvedarrow": "⤳",
    "uprightcurvearrow": "⤴",
    "downrightcurvedarrow": "⤵",
    "leftdowncurvedarrow": "⤶",
    "rightdowncurvedarrow": "⤷",
    "cwrightarcarrow": "⤸",
    "acwleftarcarrow": "⤹",
    "acwoverarcarrow": "⤺",
    "acwunderarcarrow": "⤻",
    "curvearrowrightminus": "⤼",
    "curvearrowleftplus": "⤽",
    "cwundercurvearrow": "⤾",
    "ccwundercurvearrow": "⤿",
    "acwcirclearrow": "⥀",
    "cwcirclearrow": "⥁",
    "rightarrowshortleftarrow": "⥂",
    "leftarrowshortrightarrow": "⥃",
    "shortrightarrowleftarrow": "⥄",
    "rightarrowplus": "⥅",
    "leftarrowplus": "⥆",
    "rightarrowx": "⥇",
    "leftrightarrowcircle": "⥈",
    "twoheaduparrowcircle": "⥉",
    "leftrightharpoonupdown": "⥊",
    "leftrightharpoondownup": "⥋",
    "updownharpoonrightleft": "⥌",
    "updownharpoonleftright": "⥍",
    "leftrightharpoonupup": "⥎",
    "updownharpoonrightright": "⥏",
    "leftrightharpoondowndown": "⥐",
    "updownharpoonleftleft": "⥑",
    "barleftharpoonup": "⥒",
    "rightharpoonupbar": "⥓",
    "barupharpoonright": "⥔",
    "downharpoonrightbar": "⥕",
    "barleftharpoondown": "⥖",
    "rightharpoondownbar": "⥗",
    "barupharpoonleft": "⥘",
    "downharpoonleftbar": "⥙",
    "leftharpoonupbar": "⥚",
    "barrightharpoonup": "⥛",
    "upharpoonrightbar": "⥜",
    "bardownharpoonright": "⥝",
    "leftharpoondownbar": "⥞",
    "barrightharpoondown": "⥟",
    "upharpoonleftbar": "⥠",
    "bardownharpoonleft": "⥡",
    "leftharpoonsupdown": "⥢",
    "upharpoonsleftright": "⥣",
    "rightharpoonsupdown": "⥤",
    "downharpoonsleftright": "⥥",
    "leftrightharpoonsup": "⥦",
    "leftrightharpoonsdown": "⥧",
    "rightleftharpoonsup": "⥨",
    "rightleftharpoonsdown": "⥩",
    "leftharpoonupdash": "⥪",
    "dashleftharpoondown": "⥫",
    "rightharpoonupdash": "⥬",
    "dashrightharpoondown": "⥭",
    "updownharpoonsleftright": "⥮",
    "downupharpoonsleftright": "⥯",
    "rightimply": "⥰",
    "equalrightarrow": "⥱",
    "similarrightarrow": "⥲",
    "leftarrowsimilar": "⥳",
    "rightarrowsimilar": "⥴",
    "rightarrowapprox": "⥵",
    "ltlarr": "⥶",
    "leftarrowless": "⥷",
    "gtrarr": "⥸",
    "subrarr": "⥹",
    "leftarrowsubset": "⥺",
    "suplarr": "⥻",
    "leftfishtail": "⥼",
    "rightfishtail": "⥽",
    "upfishtail": "⥾",
    "downfishtail": "⥿",
    "Vvert": "⦀",
    "mdsmblkcircle": "⦁",
    "typecolon": "⦂",
    "lBrace": "⦃",
    "rBrace": "⦄",
    "lParen": "⦅",
    "rParen": "⦆",
    "llparenthesis": "⦇",
    "rrparenthesis": "⦈",
    "llangle": "⦉",
    "rrangle": "⦊",
    "lbrackubar": "⦋",
    "rbrackubar": "⦌",
    "lbrackultick": "⦍",
    "rbracklrtick": "⦎",
    "lbracklltick": "⦏",
    "rbrackurtick": "⦐",
    "langledot": "⦑",
    "rangledot": "⦒",
    "lparenless": "⦓",
    "rparengtr": "⦔",
    "Lparengtr": "⦕",
    "Rparenless": "⦖",
    "lblkbrbrak": "⦗",
    "rblkbrbrak": "⦘",
    "fourvdots": "⦙",
    "vzigzag": "⦚",
    "measuredangleleft": "⦛",
    "rightanglesqr": "⦜",
    "rightanglemdot": "⦝",
    "angles": "⦞",
    "angdnr": "⦟",
    "gtlpar": "⦠",
    "sphericalangleup": "⦡",
    "turnangle": "⦢",
    "revangle": "⦣",
    "angleubar": "⦤",
    "revangleubar": "⦥",
    "wideangledown": "⦦",
    "wideangleup": "⦧",
    "measanglerutone": "⦨",
    "measanglelutonw": "⦩",
    "measanglerdtose": "⦪",
    "measangleldtosw": "⦫",
    "measangleurtone": "⦬",
    "measangleultonw": "⦭",
    "measangledrtose": "⦮",
    "measangledltosw": "⦯",
    "revemptyset": "⦰",
    "emptysetobar": "⦱",
    "emptysetocirc": "⦲",
    "emptysetoarr": "⦳",
    "emptysetoarrl": "⦴",
    "circlehbar": "⦵",
    "circledvert": "⦶",
    "circledparallel": "⦷",
    "obslash": "⦸",
    "operp": "⦹",
    "obot": "⦺",
    "olcross": "⦻",
    "odotslashdot": "⦼",
    "uparrowoncircle": "⦽",
    "circledwhitebullet": "⦾",
    "circledbullet": "⦿",
    "olessthan": "⧀",
    "ogreaterthan": "⧁",
    "cirscir": "⧂",
    "cirE": "⧃",
    "boxdiag": "⧄",
    "boxbslash": "⧅",
    "boxast": "⧆",
    "boxcircle": "⧇",
    "boxbox": "⧈",
    "boxonbox": "⧉",
    "triangleodot": "⧊",
    "triangleubar": "⧋",
    "triangles": "⧌",
    "triangleserifs": "⧍",
    "rtriltri": "⧎",
    "ltrivb": "⧏",
    "vbrtri": "⧐",
    "lfbowtie": "⧑",
    "rfbowtie": "⧒",
    "fbowtie": "⧓",
    "lftimes": "⧔",
    "rftimes": "⧕",
    "hourglass": "⧖",
    "blackhourglass": "⧗",
    "lvzigzag": "⧘",
    "rvzigzag": "⧙",
    "Lvzigzag": "⧚",
    "Rvzigzag": "⧛",
    "iinfin": "⧜",
    "tieinfty": "⧝",
    "nvinfty": "⧞",
    "dualmap": "⧟",
    "laplac": "⧠",
    "lrtriangleeq": "⧡",
    "shuffle": "⧢",
    "eparsl": "⧣",
    "smeparsl": "⧤",
    "eqvparsl": "⧥",
    "gleichstark": "⧦",
    "thermod": "⧧",
    "downtriangleleftblack": "⧨",
    "downtrianglerightblack": "⧩",
    "blackdiamonddownarrow": "⧪",
    "mdlgblklozenge": "⧫",
    "circledownarrow": "⧬",
    "blackcircledownarrow": "⧭",
    "errbarsquare": "⧮",
    "errbarblacksquare": "⧯",
    "errbardiamond": "⧰",
    "errbarblackdiamond": "⧱",
    "errbarcircle": "⧲",
    "errbarblackcircle": "⧳",
    "ruledelayed": "⧴",
    "setminus": "⧵",
    "dsol": "⧶",
    "rsolbar": "⧷",
    "xsol": "⧸",
    "xbsol": "⧹",
    "doubleplus": "⧺",
    "tripleplus": "⧻",
    "lcurvyangle": "⧼",
    "rcurvyangle": "⧽",
    "tplus": "⧾",
    "tminus": "⧿",
    "bigodot": "⨀",
    "bigoplus": "⨁",
    "bigotimes": "⨂",
    "bigcupdot": "⨃",
    "biguplus": "⨄",
    "bigsqcap": "⨅",
    "bigsqcup": "⨆",
    "conjquant": "⨇",
    "disjquant": "⨈",
    "bigtimes": "⨉",
    "modtwosum": "⨊",
    "sumint": "⨋",
    "iiiint": "⨌",
    "intbar": "⨍",
    "intBar": "⨎",
    "fint": "⨏",
    "cirfnint": "⨐",
    "awint": "⨑",
    "rppolint": "⨒",
    "scpolint": "⨓",
    "npolint": "⨔",
    "pointint": "⨕",
    "sqint": "⨖",
    "intlarhk": "⨗",
    "intx": "⨘",
    "intcap": "⨙",
    "intcup": "⨚",
    "upint": "⨛",
    "lowint": "⨜",
    "Join": "⨝",
    "bigtriangleleft": "⨞",
    "zcmp": "⨟",
    "zpipe": "⨠",
    "zproject": "⨡",
    "ringplus": "⨢",
    "plushat": "⨣",
    "simplus": "⨤",
    "plusdot": "⨥",
    "plussim": "⨦",
    "plussubtwo": "⨧",
    "plustrif": "⨨",
    "commaminus": "⨩",
    "minusdot": "⨪",
    "minusfdots": "⨫",
    "minusrdots": "⨬",
    "opluslhrim": "⨭",
    "oplusrhrim": "⨮",
    "vectimes": "⨯",
    "dottimes": "⨰",
    "timesbar": "⨱",
    "btimes": "⨲",
    "smashtimes": "⨳",
    "otimeslhrim": "⨴",
    "otimesrhrim": "⨵",
    "otimeshat": "⨶",
    "Otimes": "⨷",
    "odiv": "⨸",
    "triangleplus": "⨹",
    "triangleminus": "⨺",
    "triangletimes": "⨻",
    "intprod": "⨼",
    "intprodr": "⨽",
    "fcmp": "⨾",
    "amalg": "⨿",
    "capdot": "⩀",
    "uminus": "⩁",
    "barcup": "⩂",
    "barcap": "⩃",
    "capwedge": "⩄",
    "cupvee": "⩅",
    "cupovercap": "⩆",
    "capovercup": "⩇",
    "cupbarcap": "⩈",
    "capbarcup": "⩉",
    "twocups": "⩊",
    "twocaps": "⩋",
    "closedvarcup": "⩌",
    "closedvarcap": "⩍",
    "Sqcap": "⩎",
    "Sqcup": "⩏",
    "closedvarcupsmashprod": "⩐",
    "wedgeodot": "⩑",
    "veeodot": "⩒",
    "Wedge": "⩓",
    "Vee": "⩔",
    "wedgeonwedge": "⩕",
    "veeonvee": "⩖",
    "bigslopedvee": "⩗",
    "bigslopedwedge": "⩘",
    "veeonwedge": "⩙",
    "wedgemidvert": "⩚",
    "veemidvert": "⩛",
    "midbarwedge": "⩜",
    "midbarvee": "⩝",
    "doublebarwedge": "⩞",
    "wedgebar": "⩟",
    "wedgedoublebar": "⩠",
    "varveebar": "⩡",
    "doublebarvee": "⩢",
    "veedoublebar": "⩣",
    "dsub": "⩤",
    "rsub": "⩥",
    "eqdot": "⩦",
    "dotequiv": "⩧",
    "equivVert": "⩨",
    "equivVvert": "⩩",
    "dotsim": "⩪",
    "simrdots": "⩫",
    "simminussim": "⩬",
    "congdot": "⩭",
    "asteq": "⩮",
    "hatapprox": "⩯",
    "approxeqq": "⩰",
    "eqqplus": "⩱",
    "pluseqq": "⩲",
    "eqqsim": "⩳",
    "Coloneq": "⩴",
    "eqeq": "⩵",
    "eqeqeq": "⩶",
    "ddotseq": "⩷",
    "equivDD": "⩸",
    "ltcir": "⩹",
    "gtcir": "⩺",
    "ltquest": "⩻",
    "gtquest": "⩼",
    "leqslant": "⩽",
    "geqslant": "⩾",
    "lesdot": "⩿",
    "gesdot": "⪀",
    "lesdoto": "⪁",
    "gesdoto": "⪂",
    "lesdotor": "⪃",
    "gesdotol": "⪄",
    "lessapprox": "⪅",
    "gtrapprox": "⪆",
    "lneq": "⪇",
    "gneq": "⪈",
    "lnapprox": "⪉",
    "gnapprox": "⪊",
    "lesseqqgtr": "⪋",
    "gtreqqless": "⪌",
    "lsime": "⪍",
    "gsime": "⪎",
    "lsimg": "⪏",
    "gsiml": "⪐",
    "lgE": "⪑",
    "glE": "⪒",
    "lesges": "⪓",
    "gesles": "⪔",
    "eqslantless": "⪕",
    "eqslantgtr": "⪖",
    "elsdot": "⪗",
    "egsdot": "⪘",
    "eqqless": "⪙",
    "eqqgtr": "⪚",
    "eqqslantless": "⪛",
    "eqqslantgtr": "⪜",
    "simless": "⪝",
    "simgtr": "⪞",
    "simlE": "⪟",
    "simgE": "⪠",
    "Lt": "⪡",
    "Gt": "⪢",
    "partialmeetcontraction": "⪣",
    "glj": "⪤",
    "gla": "⪥",
    "ltcc": "⪦",
    "gtcc": "⪧",
    "lescc": "⪨",
    "gescc": "⪩",
    "smt": "⪪",
    "lat": "⪫",
    "smte": "⪬",
    "late": "⪭",
    "bumpeqq": "⪮",
    "preceq": "⪯",
    "succeq": "⪰",
    "precneq": "⪱",
    "succneq": "⪲",
    "preceqq": "⪳",
    "succeqq": "⪴",
    "precneqq": "⪵",
    "succneqq": "⪶",
    "precapprox": "⪷",
    "succapprox": "⪸",
    "precnapprox": "⪹",
    "succnapprox": "⪺",
    "Prec": "⪻",
    "Succ": "⪼",
    "subsetdot": "⪽",
    "supsetdot": "⪾",
    "subsetplus": "⪿",
    "supsetplus": "⫀",
    "submult": "⫁",
    "supmult": "⫂",
    "subedot": "⫃",
    "supedot": "⫄",
    "subseteqq": "⫅",
    "supseteqq": "⫆",
    "subsim": "⫇",
    "supsim": "⫈",
    "subsetapprox": "⫉",
    "supsetapprox": "⫊",
    "subsetneqq": "⫋",
    "supsetneqq": "⫌",
    "lsqhook": "⫍",
    "rsqhook": "⫎",
    "csub": "⫏",
    "csup": "⫐",
    "csube": "⫑",
    "csupe": "⫒",
    "subsup": "⫓",
    "supsub": "⫔",
    "subsub": "⫕",
    "supsup": "⫖",
    "suphsub": "⫗",
    "supdsub": "⫘",
    "forkv": "⫙",
    "topfork": "⫚",
    "mlcp": "⫛",
    "forks": "⫝̸",
    "forksnot": "⫝",
    "shortlefttack": "⫞",
    "shortdowntack": "⫟",
    "shortuptack": "⫠",
    "perps": "⫡",
    "vDdash": "⫢",
    "dashV": "⫣",
    "Dashv": "⫤",
    "DashV": "⫥",
    "varVdash": "⫦",
    "Barv": "⫧",
    "vBar": "⫨",
    "vBarv": "⫩",
    "barV": "⫪",
    "Vbar": "⫫",
    "Not": "⫬",
    "bNot": "⫭",
    "revnmid": "⫮",
    "cirmid": "⫯",
    "midcir": "⫰",
    "topcir": "⫱",
    "nhpar": "⫲",
    "parsim": "⫳",
    "interleave": "⫴",
    "nhVvert": "⫵",
    "threedotcolon": "⫶",
    "lllnest": "⫷",
    "gggnest": "⫸",
    "leqqslant": "⫹",
    "geqqslant": "⫺",
    "trslash": "⫻",
    "biginterleave": "⫼",
    "sslash": "⫽",
    "talloblong": "⫾",
    "bigtalloblong": "⫿",
    "squaretopblack": "⬒",
    "squarebotblack": "⬓",
    "squareurblack": "⬔",
    "squarellblack": "⬕",
    "diamondleftblack": "⬖",
    "diamondrightblack": "⬗",
    "diamondtopblack": "⬘",
    "diamondbotblack": "⬙",
    "dottedsquare": "⬚",
    "lgblksquare": "⬛",
    "lgwhtsquare": "⬜",
    "vysmblksquare": "⬝",
    "vysmwhtsquare": "⬞",
    "pentagonblack": "⬟",
    "pentagon": "⬠",
    "varhexagon": "⬡",
    "varhexagonblack": "⬢",
    "hexagonblack": "⬣",
    "lgblkcircle": "⬤",
    "mdblkdiamond": "⬥",
    "mdwhtdiamond": "⬦",
    "mdblklozenge": "⬧",
    "mdwhtlozenge": "⬨",
    "smblkdiamond": "⬩",
    "smblklozenge": "⬪",
    "smwhtlozenge": "⬫",
    "blkhorzoval": "⬬",
    "whthorzoval": "⬭",
    "blkvertoval": "⬮",
    "whtvertoval": "⬯",
    "circleonleftarrow": "⬰",
    "leftthreearrows": "⬱",
    "leftarrowonoplus": "⬲",
    "longleftsquigarrow": "⬳",
    "nvtwoheadleftarrow": "⬴",
    "nVtwoheadleftarrow": "⬵",
    "twoheadmapsfrom": "⬶",
    "twoheadleftdbkarrow": "⬷",
    "leftdotarrow": "⬸",
    "nvleftarrowtail": "⬹",
    "nVleftarrowtail": "⬺",
    "twoheadleftarrowtail": "⬻",
    "nvtwoheadleftarrowtail": "⬼",
    "nVtwoheadleftarrowtail": "⬽",
    "leftarrowx": "⬾",
    "leftcurvedarrow": "⬿",
    "equalleftarrow": "⭀",
    "bsimilarleftarrow": "⭁",
    "leftarrowbackapprox": "⭂",
    "rightarrowgtr": "⭃",
    "rightarrowsupset": "⭄",
    "LLeftarrow": "⭅",
    "RRightarrow": "⭆",
    "bsimilarrightarrow": "⭇",
    "rightarrowbackapprox": "⭈",
    "similarleftarrow": "⭉",
    "leftarrowapprox": "⭊",
    "leftarrowbsimilar": "⭋",
    "rightarrowbsimilar": "⭌",
    "medwhitestar": "⭐",
    "medblackstar": "⭑",
    "smwhitestar": "⭒",
    "rightpentagonblack": "⭓",
    "rightpentagon": "⭔",
    "postalmark": "〒",
    "hzigzag": "〰",
    "mbfA": "𝐀",
    "mbfB": "𝐁",
    "mbfC": "𝐂",
    "mbfD": "𝐃",
    "mbfE": "𝐄",
    "mbfF": "𝐅",
    "mbfG": "𝐆",
    "mbfH": "𝐇",
    "mbfI": "𝐈",
    "mbfJ": "𝐉",
    "mbfK": "𝐊",
    "mbfL": "𝐋",
    "mbfM": "𝐌",
    "mbfN": "𝐍",
    "mbfO": "𝐎",
    "mbfP": "𝐏",
    "mbfQ": "𝐐",
    "mbfR": "𝐑",
    "mbfS": "𝐒",
    "mbfT": "𝐓",
    "mbfU": "𝐔",
    "mbfV": "𝐕",
    "mbfW": "𝐖",
    "mbfX": "𝐗",
    "mbfY": "𝐘",
    "mbfZ": "𝐙",
    "mbfa": "𝐚",
    "mbfb": "𝐛",
    "mbfc": "𝐜",
    "mbfd": "𝐝",
    "mbfe": "𝐞",
    "mbff": "𝐟",
    "mbfg": "𝐠",
    "mbfh": "𝐡",
    "mbfi": "𝐢",
    "mbfj": "𝐣",
    "mbfk": "𝐤",
    "mbfl": "𝐥",
    "mbfm": "𝐦",
    "mbfn": "𝐧",
    "mbfo": "𝐨",
    "mbfp": "𝐩",
    "mbfq": "𝐪",
    "mbfr": "𝐫",
    "mbfs": "𝐬",
    "mbft": "𝐭",
    "mbfu": "𝐮",
    "mbfv": "𝐯",
    "mbfw": "𝐰",
    "mbfx": "𝐱",
    "mbfy": "𝐲",
    "mbfz": "𝐳",
    "mitA": "𝐴",
    "mitB": "𝐵",
    "mitC": "𝐶",
    "mitD": "𝐷",
    "mitE": "𝐸",
    "mitF": "𝐹",
    "mitG": "𝐺",
    "mitH": "𝐻",
    "mitI": "𝐼",
    "mitJ": "𝐽",
    "mitK": "𝐾",
    "mitL": "𝐿",
    "mitM": "𝑀",
    "mitN": "𝑁",
    "mitO": "𝑂",
    "mitP": "𝑃",
    "mitQ": "𝑄",
    "mitR": "𝑅",
    "mitS": "𝑆",
    "mitT": "𝑇",
    "mitU": "𝑈",
    "mitV": "𝑉",
    "mitW": "𝑊",
    "mitX": "𝑋",
    "mitY": "𝑌",
    "mitZ": "𝑍",
    "mita": "𝑎",
    "mitb": "𝑏",
    "mitc": "𝑐",
    "mitd": "𝑑",
    "mite": "𝑒",
    "mitf": "𝑓",
    "mitg": "𝑔",
    "miti": "𝑖",
    "mitj": "𝑗",
    "mitk": "𝑘",
    "mitl": "𝑙",
    "mitm": "𝑚",
    "mitn": "𝑛",
    "mito": "𝑜",
    "mitp": "𝑝",
    "mitq": "𝑞",
    "mitr": "𝑟",
    "mits": "𝑠",
    "mitt": "𝑡",
    "mitu": "𝑢",
    "mitv": "𝑣",
    "mitw": "𝑤",
    "mitx": "𝑥",
    "mity": "𝑦",
    "mitz": "𝑧",
    "mbfitA": "𝑨",
    "mbfitB": "𝑩",
    "mbfitC": "𝑪",
    "mbfitD": "𝑫",
    "mbfitE": "𝑬",
    "mbfitF": "𝑭",
    "mbfitG": "𝑮",
    "mbfitH": "𝑯",
    "mbfitI": "𝑰",
    "mbfitJ": "𝑱",
    "mbfitK": "𝑲",
    "mbfitL": "𝑳",
    "mbfitM": "𝑴",
    "mbfitN": "𝑵",
    "mbfitO": "𝑶",
    "mbfitP": "𝑷",
    "mbfitQ": "𝑸",
    "mbfitR": "𝑹",
    "mbfitS": "𝑺",
    "mbfitT": "𝑻",
    "mbfitU": "𝑼",
    "mbfitV": "𝑽",
    "mbfitW": "𝑾",
    "mbfitX": "𝑿",
    "mbfitY": "𝒀",
    "mbfitZ": "𝒁",
    "mbfita": "𝒂",
    "mbfitb": "𝒃",
    "mbfitc": "𝒄",
    "mbfitd": "𝒅",
    "mbfite": "𝒆",
    "mbfitf": "𝒇",
    "mbfitg": "𝒈",
    "mbfith": "𝒉",
    "mbfiti": "𝒊",
    "mbfitj": "𝒋",
    "mbfitk": "𝒌",
    "mbfitl": "𝒍",
    "mbfitm": "𝒎",
    "mbfitn": "𝒏",
    "mbfito": "𝒐",
    "mbfitp": "𝒑",
    "mbfitq": "𝒒",
    "mbfitr": "𝒓",
    "mbfits": "𝒔",
    "mbfitt": "𝒕",
    "mbfitu": "𝒖",
    "mbfitv": "𝒗",
    "mbfitw": "𝒘",
    "mbfitx": "𝒙",
    "mbfity": "𝒚",
    "mbfitz": "𝒛",
    "mscrA": "𝒜",
    "mscrC": "𝒞",
    "mscrD": "𝒟",
    "mscrG": "𝒢",
    "mscrJ": "𝒥",
    "mscrK": "𝒦",
    "mscrN": "𝒩",
    "mscrO": "𝒪",
    "mscrP": "𝒫",
    "mscrQ": "𝒬",
    "mscrS": "𝒮",
    "mscrT": "𝒯",
    "mscrU": "𝒰",
    "mscrV": "𝒱",
    "mscrW": "𝒲",
    "mscrX": "𝒳",
    "mscrY": "𝒴",
    "mscrZ": "𝒵",
    "mscra": "𝒶",
    "mscrb": "𝒷",
    "mscrc": "𝒸",
    "mscrd": "𝒹",
    "mscrf": "𝒻",
    "mscrh": "𝒽",
    "mscri": "𝒾",
    "mscrj": "𝒿",
    "mscrk": "𝓀",
    "mscrl": "𝓁",
    "mscrm": "𝓂",
    "mscrn": "𝓃",
    "mscrp": "𝓅",
    "mscrq": "𝓆",
    "mscrr": "𝓇",
    "mscrs": "𝓈",
    "mscrt": "𝓉",
    "mscru": "𝓊",
    "mscrv": "𝓋",
    "mscrw": "𝓌",
    "mscrx": "𝓍",
    "mscry": "𝓎",
    "mscrz": "𝓏",
    "mbfscrA": "𝓐",
    "mbfscrB": "𝓑",
    "mbfscrC": "𝓒",
    "mbfscrD": "𝓓",
    "mbfscrE": "𝓔",
    "mbfscrF": "𝓕",
    "mbfscrG": "𝓖",
    "mbfscrH": "𝓗",
    "mbfscrI": "𝓘",
    "mbfscrJ": "𝓙",
    "mbfscrK": "𝓚",
    "mbfscrL": "𝓛",
    "mbfscrM": "𝓜",
    "mbfscrN": "𝓝",
    "mbfscrO": "𝓞",
    "mbfscrP": "𝓟",
    "mbfscrQ": "𝓠",
    "mbfscrR": "𝓡",
    "mbfscrS": "𝓢",
    "mbfscrT": "𝓣",
    "mbfscrU": "𝓤",
    "mbfscrV": "𝓥",
    "mbfscrW": "𝓦",
    "mbfscrX": "𝓧",
    "mbfscrY": "𝓨",
    "mbfscrZ": "𝓩",
    "mbfscra": "𝓪",
    "mbfscrb": "𝓫",
    "mbfscrc": "𝓬",
    "mbfscrd": "𝓭",
    "mbfscre": "𝓮",
    "mbfscrf": "𝓯",
    "mbfscrg": "𝓰",
    "mbfscrh": "𝓱",
    "mbfscri": "𝓲",
    "mbfscrj": "𝓳",
    "mbfscrk": "𝓴",
    "mbfscrl": "𝓵",
    "mbfscrm": "𝓶",
    "mbfscrn": "𝓷",
    "mbfscro": "𝓸",
    "mbfscrp": "𝓹",
    "mbfscrq": "𝓺",
    "mbfscrr": "𝓻",
    "mbfscrs": "𝓼",
    "mbfscrt": "𝓽",
    "mbfscru": "𝓾",
    "mbfscrv": "𝓿",
    "mbfscrw": "𝔀",
    "mbfscrx": "𝔁",
    "mbfscry": "𝔂",
    "mbfscrz": "𝔃",
    "mfrakA": "𝔄",
    "mfrakB": "𝔅",
    "mfrakD": "𝔇",
    "mfrakE": "𝔈",
    "mfrakF": "𝔉",
    "mfrakG": "𝔊",
    "mfrakJ": "𝔍",
    "mfrakK": "𝔎",
    "mfrakL": "𝔏",
    "mfrakM": "𝔐",
    "mfrakN": "𝔑",
    "mfrakO": "𝔒",
    "mfrakP": "𝔓",
    "mfrakQ": "𝔔",
    "mfrakS": "𝔖",
    "mfrakT": "𝔗",
    "mfrakU": "𝔘",
    "mfrakV": "𝔙",
    "mfrakW": "𝔚",
    "mfrakX": "𝔛",
    "mfrakY": "𝔜",
    "mfraka": "𝔞",
    "mfrakb": "𝔟",
    "mfrakc": "𝔠",
    "mfrakd": "𝔡",
    "mfrake": "𝔢",
    "mfrakf": "𝔣",
    "mfrakg": "𝔤",
    "mfrakh": "𝔥",
    "mfraki": "𝔦",
    "mfrakj": "𝔧",
    "mfrakk": "𝔨",
    "mfrakl": "𝔩",
    "mfrakm": "𝔪",
    "mfrakn": "𝔫",
    "mfrako": "𝔬",
    "mfrakp": "𝔭",
    "mfrakq": "𝔮",
    "mfrakr": "𝔯",
    "mfraks": "𝔰",
    "mfrakt": "𝔱",
    "mfraku": "𝔲",
    "mfrakv": "𝔳",
    "mfrakw": "𝔴",
    "mfrakx": "𝔵",
    "mfraky": "𝔶",
    "mfrakz": "𝔷",
    "BbbA": "𝔸",
    "BbbB": "𝔹",
    "BbbD": "𝔻",
    "BbbE": "𝔼",
    "BbbF": "𝔽",
    "BbbG": "𝔾",
    "BbbI": "𝕀",
    "BbbJ": "𝕁",
    "BbbK": "𝕂",
    "BbbL": "𝕃",
    "BbbM": "𝕄",
    "BbbO": "𝕆",
    "BbbS": "𝕊",
    "BbbT": "𝕋",
    "BbbU": "𝕌",
    "BbbV": "𝕍",
    "BbbW": "𝕎",
    "BbbX": "𝕏",
    "BbbY": "𝕐",
    "Bbba": "𝕒",
    "Bbbb": "𝕓",
    "Bbbc": "𝕔",
    "Bbbd": "𝕕",
    "Bbbe": "𝕖",
    "Bbbf": "𝕗",
    "Bbbg": "𝕘",
    "Bbbh": "𝕙",
    "Bbbi": "𝕚",
    "Bbbj": "𝕛",
    "Bbbk": "𝕜",
    "Bbbl": "𝕝",
    "Bbbm": "𝕞",
    "Bbbn": "𝕟",
    "Bbbo": "𝕠",
    "Bbbp": "𝕡",
    "Bbbq": "𝕢",
    "Bbbr": "𝕣",
    "Bbbs": "𝕤",
    "Bbbt": "𝕥",
    "Bbbu": "𝕦",
    "Bbbv": "𝕧",
    "Bbbw": "𝕨",
    "Bbbx": "𝕩",
    "Bbby": "𝕪",
    "Bbbz": "𝕫",
    "mbffrakA": "𝕬",
    "mbffrakB": "𝕭",
    "mbffrakC": "𝕮",
    "mbffrakD": "𝕯",
    "mbffrakE": "𝕰",
    "mbffrakF": "𝕱",
    "mbffrakG": "𝕲",
    "mbffrakH": "𝕳",
    "mbffrakI": "𝕴",
    "mbffrakJ": "𝕵",
    "mbffrakK": "𝕶",
    "mbffrakL": "𝕷",
    "mbffrakM": "𝕸",
    "mbffrakN": "𝕹",
    "mbffrakO": "𝕺",
    "mbffrakP": "𝕻",
    "mbffrakQ": "𝕼",
    "mbffrakR": "𝕽",
    "mbffrakS": "𝕾",
    "mbffrakT": "𝕿",
    "mbffrakU": "𝖀",
    "mbffrakV": "𝖁",
    "mbffrakW": "𝖂",
    "mbffrakX": "𝖃",
    "mbffrakY": "𝖄",
    "mbffrakZ": "𝖅",
    "mbffraka": "𝖆",
    "mbffrakb": "𝖇",
    "mbffrakc": "𝖈",
    "mbffrakd": "𝖉",
    "mbffrake": "𝖊",
    "mbffrakf": "𝖋",
    "mbffrakg": "𝖌",
    "mbffrakh": "𝖍",
    "mbffraki": "𝖎",
    "mbffrakj": "𝖏",
    "mbffrakk": "𝖐",
    "mbffrakl": "𝖑",
    "mbffrakm": "𝖒",
    "mbffrakn": "𝖓",
    "mbffrako": "𝖔",
    "mbffrakp": "𝖕",
    "mbffrakq": "𝖖",
    "mbffrakr": "𝖗",
    "mbffraks": "𝖘",
    "mbffrakt": "𝖙",
    "mbffraku": "𝖚",
    "mbffrakv": "𝖛",
    "mbffrakw": "𝖜",
    "mbffrakx": "𝖝",
    "mbffraky": "𝖞",
    "mbffrakz": "𝖟",
    "msansA": "𝖠",
    "msansB": "𝖡",
    "msansC": "𝖢",
    "msansD": "𝖣",
    "msansE": "𝖤",
    "msansF": "𝖥",
    "msansG": "𝖦",
    "msansH": "𝖧",
    "msansI": "𝖨",
    "msansJ": "𝖩",
    "msansK": "𝖪",
    "msansL": "𝖫",
    "msansM": "𝖬",
    "msansN": "𝖭",
    "msansO": "𝖮",
    "msansP": "𝖯",
    "msansQ": "𝖰",
    "msansR": "𝖱",
    "msansS": "𝖲",
    "msansT": "𝖳",
    "msansU": "𝖴",
    "msansV": "𝖵",
    "msansW": "𝖶",
    "msansX": "𝖷",
    "msansY": "𝖸",
    "msansZ": "𝖹",
    "msansa": "𝖺",
    "msansb": "𝖻",
    "msansc": "𝖼",
    "msansd": "𝖽",
    "msanse": "𝖾",
    "msansf": "𝖿",
    "msansg": "𝗀",
    "msansh": "𝗁",
    "msansi": "𝗂",
    "msansj": "𝗃",
    "msansk": "𝗄",
    "msansl": "𝗅",
    "msansm": "𝗆",
    "msansn": "𝗇",
    "msanso": "𝗈",
    "msansp": "𝗉",
    "msansq": "𝗊",
    "msansr": "𝗋",
    "msanss": "𝗌",
    "msanst": "𝗍",
    "msansu": "𝗎",
    "msansv": "𝗏",
    "msansw": "𝗐",
    "msansx": "𝗑",
    "msansy": "𝗒",
    "msansz": "𝗓",
    "mbfsansA": "𝗔",
    "mbfsansB": "𝗕",
    "mbfsansC": "𝗖",
    "mbfsansD": "𝗗",
    "mbfsansE": "𝗘",
    "mbfsansF": "𝗙",
    "mbfsansG": "𝗚",
    "mbfsansH": "𝗛",
    "mbfsansI": "𝗜",
    "mbfsansJ": "𝗝",
    "mbfsansK": "𝗞",
    "mbfsansL": "𝗟",
    "mbfsansM": "𝗠",
    "mbfsansN": "𝗡",
    "mbfsansO": "𝗢",
    "mbfsansP": "𝗣",
    "mbfsansQ": "𝗤",
    "mbfsansR": "𝗥",
    "mbfsansS": "𝗦",
    "mbfsansT": "𝗧",
    "mbfsansU": "𝗨",
    "mbfsansV": "𝗩",
    "mbfsansW": "𝗪",
    "mbfsansX": "𝗫",
    "mbfsansY": "𝗬",
    "mbfsansZ": "𝗭",
    "mbfsansa": "𝗮",
    "mbfsansb": "𝗯",
    "mbfsansc": "𝗰",
    "mbfsansd": "𝗱",
    "mbfsanse": "𝗲",
    "mbfsansf": "𝗳",
    "mbfsansg": "𝗴",
    "mbfsansh": "𝗵",
    "mbfsansi": "𝗶",
    "mbfsansj": "𝗷",
    "mbfsansk": "𝗸",
    "mbfsansl": "𝗹",
    "mbfsansm": "𝗺",
    "mbfsansn": "𝗻",
    "mbfsanso": "𝗼",
    "mbfsansp": "𝗽",
    "mbfsansq": "𝗾",
    "mbfsansr": "𝗿",
    "mbfsanss": "𝘀",
    "mbfsanst": "𝘁",
    "mbfsansu": "𝘂",
    "mbfsansv": "𝘃",
    "mbfsansw": "𝘄",
    "mbfsansx": "𝘅",
    "mbfsansy": "𝘆",
    "mbfsansz": "𝘇",
    "mitsansA": "𝘈",
    "mitsansB": "𝘉",
    "mitsansC": "𝘊",
    "mitsansD": "𝘋",
    "mitsansE": "𝘌",
    "mitsansF": "𝘍",
    "mitsansG": "𝘎",
    "mitsansH": "𝘏",
    "mitsansI": "𝘐",
    "mitsansJ": "𝘑",
    "mitsansK": "𝘒",
    "mitsansL": "𝘓",
    "mitsansM": "𝘔",
    "mitsansN": "𝘕",
    "mitsansO": "𝘖",
    "mitsansP": "𝘗",
    "mitsansQ": "𝘘",
    "mitsansR": "𝘙",
    "mitsansS": "𝘚",
    "mitsansT": "𝘛",
    "mitsansU": "𝘜",
    "mitsansV": "𝘝",
    "mitsansW": "𝘞",
    "mitsansX": "𝘟",
    "mitsansY": "𝘠",
    "mitsansZ": "𝘡",
    "mitsansa": "𝘢",
    "mitsansb": "𝘣",
    "mitsansc": "𝘤",
    "mitsansd": "𝘥",
    "mitsanse": "𝘦",
    "mitsansf": "𝘧",
    "mitsansg": "𝘨",
    "mitsansh": "𝘩",
    "mitsansi": "𝘪",
    "mitsansj": "𝘫",
    "mitsansk": "𝘬",
    "mitsansl": "𝘭",
    "mitsansm": "𝘮",
    "mitsansn": "𝘯",
    "mitsanso": "𝘰",
    "mitsansp": "𝘱",
    "mitsansq": "𝘲",
    "mitsansr": "𝘳",
    "mitsanss": "𝘴",
    "mitsanst": "𝘵",
    "mitsansu": "𝘶",
    "mitsansv": "𝘷",
    "mitsansw": "𝘸",
    "mitsansx": "𝘹",
    "mitsansy": "𝘺",
    "mitsansz": "𝘻",
    "mbfitsansA": "𝘼",
    "mbfitsansB": "𝘽",
    "mbfitsansC": "𝘾",
    "mbfitsansD": "𝘿",
    "mbfitsansE": "𝙀",
    "mbfitsansF": "𝙁",
    "mbfitsansG": "𝙂",
    "mbfitsansH": "𝙃",
    "mbfitsansI": "𝙄",
    "mbfitsansJ": "𝙅",
    "mbfitsansK": "𝙆",
    "mbfitsansL": "𝙇",
    "mbfitsansM": "𝙈",
    "mbfitsansN": "𝙉",
    "mbfitsansO": "𝙊",
    "mbfitsansP": "𝙋",
    "mbfitsansQ": "𝙌",
    "mbfitsansR": "𝙍",
    "mbfitsansS": "𝙎",
    "mbfitsansT": "𝙏",
    "mbfitsansU": "𝙐",
    "mbfitsansV": "𝙑",
    "mbfitsansW": "𝙒",
    "mbfitsansX": "𝙓",
    "mbfitsansY": "𝙔",
    "mbfitsansZ": "𝙕",
    "mbfitsansa": "𝙖",
    "mbfitsansb": "𝙗",
    "mbfitsansc": "𝙘",
    "mbfitsansd": "𝙙",
    "mbfitsanse": "𝙚",
    "mbfitsansf": "𝙛",
    "mbfitsansg": "𝙜",
    "mbfitsansh": "𝙝",
    "mbfitsansi": "𝙞",
    "mbfitsansj": "𝙟",
    "mbfitsansk": "𝙠",
    "mbfitsansl": "𝙡",
    "mbfitsansm": "𝙢",
    "mbfitsansn": "𝙣",
    "mbfitsanso": "𝙤",
    "mbfitsansp": "𝙥",
    "mbfitsansq": "𝙦",
    "mbfitsansr": "𝙧",
    "mbfitsanss": "𝙨",
    "mbfitsanst": "𝙩",
    "mbfitsansu": "𝙪",
    "mbfitsansv": "𝙫",
    "mbfitsansw": "𝙬",
    "mbfitsansx": "𝙭",
    "mbfitsansy": "𝙮",
    "mbfitsansz": "𝙯",
    "mttA": "𝙰",
    "mttB": "𝙱",
    "mttC": "𝙲",
    "mttD": "𝙳",
    "mttE": "𝙴",
    "mttF": "𝙵",
    "mttG": "𝙶",
    "mttH": "𝙷",
    "mttI": "𝙸",
    "mttJ": "𝙹",
    "mttK": "𝙺",
    "mttL": "𝙻",
    "mttM": "𝙼",
    "mttN": "𝙽",
    "mttO": "𝙾",
    "mttP": "𝙿",
    "mttQ": "𝚀",
    "mttR": "𝚁",
    "mttS": "𝚂",
    "mttT": "𝚃",
    "mttU": "𝚄",
    "mttV": "𝚅",
    "mttW": "𝚆",
    "mttX": "𝚇",
    "mttY": "𝚈",
    "mttZ": "𝚉",
    "mtta": "𝚊",
    "mttb": "𝚋",
    "mttc": "𝚌",
    "mttd": "𝚍",
    "mtte": "𝚎",
    "mttf": "𝚏",
    "mttg": "𝚐",
    "mtth": "𝚑",
    "mtti": "𝚒",
    "mttj": "𝚓",
    "mttk": "𝚔",
    "mttl": "𝚕",
    "mttm": "𝚖",
    "mttn": "𝚗",
    "mtto": "𝚘",
    "mttp": "𝚙",
    "mttq": "𝚚",
    "mttr": "𝚛",
    "mtts": "𝚜",
    "mttt": "𝚝",
    "mttu": "𝚞",
    "mttv": "𝚟",
    "mttw": "𝚠",
    "mttx": "𝚡",
    "mtty": "𝚢",
    "mttz": "𝚣",
    "imath": "𝚤",
    "jmath": "𝚥",
    "mbfAlpha": "𝚨",
    "mbfBeta": "𝚩",
    "mbfGamma": "𝚪",
    "mbfDelta": "𝚫",
    "mbfEpsilon": "𝚬",
    "mbfZeta": "𝚭",
    "mbfEta": "𝚮",
    "mbfTheta": "𝚯",
    "mbfIota": "𝚰",
    "mbfKappa": "𝚱",
    "mbfLambda": "𝚲",
    "mbfMu": "𝚳",
    "mbfNu": "𝚴",
    "mbfXi": "𝚵",
    "mbfOmicron": "𝚶",
    "mbfPi": "𝚷",
    "mbfRho": "𝚸",
    "mbfvarTheta": "𝚹",
    "mbfSigma": "𝚺",
    "mbfTau": "𝚻",
    "mbfUpsilon": "𝚼",
    "mbfPhi": "𝚽",
    "mbfChi": "𝚾",
    "mbfPsi": "𝚿",
    "mbfOmega": "𝛀",
    "mbfnabla": "𝛁",
    "mbfalpha": "𝛂",
    "mbfbeta": "𝛃",
    "mbfgamma": "𝛄",
    "mbfdelta": "𝛅",
    "mbfvarepsilon": "𝛆",
    "mbfzeta": "𝛇",
    "mbfeta": "𝛈",
    "mbftheta": "𝛉",
    "mbfiota": "𝛊",
    "mbfkappa": "𝛋",
    "mbflambda": "𝛌",
    "mbfmu": "𝛍",
    "mbfnu": "𝛎",
    "mbfxi": "𝛏",
    "mbfomicron": "𝛐",
    "mbfpi": "𝛑",
    "mbfrho": "𝛒",
    "mbfvarsigma": "𝛓",
    "mbfsigma": "𝛔",
    "mbftau": "𝛕",
    "mbfupsilon": "𝛖",
    "mbfvarphi": "𝛗",
    "mbfchi": "𝛘",
    "mbfpsi": "𝛙",
    "mbfomega": "𝛚",
    "mbfpartial": "𝛛",
    "mbfepsilon": "𝛜",
    "mbfvartheta": "𝛝",
    "mbfvarkappa": "𝛞",
    "mbfphi": "𝛟",
    "mbfvarrho": "𝛠",
    "mbfvarpi": "𝛡",
    "mitAlpha": "𝛢",
    "mitBeta": "𝛣",
    "mitGamma": "𝛤",
    "mitDelta": "𝛥",
    "mitEpsilon": "𝛦",
    "mitZeta": "𝛧",
    "mitEta": "𝛨",
    "mitTheta": "𝛩",
    "mitIota": "𝛪",
    "mitKappa": "𝛫",
    "mitLambda": "𝛬",
    "mitMu": "𝛭",
    "mitNu": "𝛮",
    "mitXi": "𝛯",
    "mitOmicron": "𝛰",
    "mitPi": "𝛱",
    "mitRho": "𝛲",
    "mitvarTheta": "𝛳",
    "mitSigma": "𝛴",
    "mitTau": "𝛵",
    "mitUpsilon": "𝛶",
    "mitPhi": "𝛷",
    "mitChi": "𝛸",
    "mitPsi": "𝛹",
    "mitOmega": "𝛺",
    "mitnabla": "𝛻",
    "mitalpha": "𝛼",
    "mitbeta": "𝛽",
    "mitgamma": "𝛾",
    "mitdelta": "𝛿",
    "mitvarepsilon": "𝜀",
    "mitzeta": "𝜁",
    "miteta": "𝜂",
    "mittheta": "𝜃",
    "mitiota": "𝜄",
    "mitkappa": "𝜅",
    "mitlambda": "𝜆",
    "mitmu": "𝜇",
    "mitnu": "𝜈",
    "mitxi": "𝜉",
    "mitomicron": "𝜊",
    "mitpi": "𝜋",
    "mitrho": "𝜌",
    "mitvarsigma": "𝜍",
    "mitsigma": "𝜎",
    "mittau": "𝜏",
    "mitupsilon": "𝜐",
    "mitvarphi": "𝜑",
    "mitchi": "𝜒",
    "mitpsi": "𝜓",
    "mitomega": "𝜔",
    "mitpartial": "𝜕",
    "mitepsilon": "𝜖",
    "mitvartheta": "𝜗",
    "mitvarkappa": "𝜘",
    "mitphi": "𝜙",
    "mitvarrho": "𝜚",
    "mitvarpi": "𝜛",
    "mbfitAlpha": "𝜜",
    "mbfitBeta": "𝜝",
    "mbfitGamma": "𝜞",
    "mbfitDelta": "𝜟",
    "mbfitEpsilon": "𝜠",
    "mbfitZeta": "𝜡",
    "mbfitEta": "𝜢",
    "mbfitTheta": "𝜣",
    "mbfitIota": "𝜤",
    "mbfitKappa": "𝜥",
    "mbfitLambda": "𝜦",
    "mbfitMu": "𝜧",
    "mbfitNu": "𝜨",
    "mbfitXi": "𝜩",
    "mbfitOmicron": "𝜪",
    "mbfitPi": "𝜫",
    "mbfitRho": "𝜬",
    "mbfitvarTheta": "𝜭",
    "mbfitSigma": "𝜮",
    "mbfitTau": "𝜯",
    "mbfitUpsilon": "𝜰",
    "mbfitPhi": "𝜱",
    "mbfitChi": "𝜲",
    "mbfitPsi": "𝜳",
    "mbfitOmega": "𝜴",
    "mbfitnabla": "𝜵",
    "mbfitalpha": "𝜶",
    "mbfitbeta": "𝜷",
    "mbfitgamma": "𝜸",
    "mbfitdelta": "𝜹",
    "mbfitvarepsilon": "𝜺",
    "mbfitzeta": "𝜻",
    "mbfiteta": "𝜼",
    "mbfittheta": "𝜽",
    "mbfitiota": "𝜾",
    "mbfitkappa": "𝜿",
    "mbfitlambda": "𝝀",
    "mbfitmu": "𝝁",
    "mbfitnu": "𝝂",
    "mbfitxi": "𝝃",
    "mbfitomicron": "𝝄",
    "mbfitpi": "𝝅",
    "mbfitrho": "𝝆",
    "mbfitvarsigma": "𝝇",
    "mbfitsigma": "𝝈",
    "mbfittau": "𝝉",
    "mbfitupsilon": "𝝊",
    "mbfitvarphi": "𝝋",
    "mbfitchi": "𝝌",
    "mbfitpsi": "𝝍",
    "mbfitomega": "𝝎",
    "mbfitpartial": "𝝏",
    "mbfitepsilon": "𝝐",
    "mbfitvartheta": "𝝑",
    "mbfitvarkappa": "𝝒",
    "mbfitphi": "𝝓",
    "mbfitvarrho": "𝝔",
    "mbfitvarpi": "𝝕",
    "mbfsansAlpha": "𝝖",
    "mbfsansBeta": "𝝗",
    "mbfsansGamma": "𝝘",
    "mbfsansDelta": "𝝙",
    "mbfsansEpsilon": "𝝚",
    "mbfsansZeta": "𝝛",
    "mbfsansEta": "𝝜",
    "mbfsansTheta": "𝝝",
    "mbfsansIota": "𝝞",
    "mbfsansKappa": "𝝟",
    "mbfsansLambda": "𝝠",
    "mbfsansMu": "𝝡",
    "mbfsansNu": "𝝢",
    "mbfsansXi": "𝝣",
    "mbfsansOmicron": "𝝤",
    "mbfsansPi": "𝝥",
    "mbfsansRho": "𝝦",
    "mbfsansvarTheta": "𝝧",
    "mbfsansSigma": "𝝨",
    "mbfsansTau": "𝝩",
    "mbfsansUpsilon": "𝝪",
    "mbfsansPhi": "𝝫",
    "mbfsansChi": "𝝬",
    "mbfsansPsi": "𝝭",
    "mbfsansOmega": "𝝮",
    "mbfsansnabla": "𝝯",
    "mbfsansalpha": "𝝰",
    "mbfsansbeta": "𝝱",
    "mbfsansgamma": "𝝲",
    "mbfsansdelta": "𝝳",
    "mbfsansvarepsilon": "𝝴",
    "mbfsanszeta": "𝝵",
    "mbfsanseta": "𝝶",
    "mbfsanstheta": "𝝷",
    "mbfsansiota": "𝝸",
    "mbfsanskappa": "𝝹",
    "mbfsanslambda": "𝝺",
    "mbfsansmu": "𝝻",
    "mbfsansnu": "𝝼",
    "mbfsansxi": "𝝽",
    "mbfsansomicron": "𝝾",
    "mbfsanspi": "𝝿",
    "mbfsansrho": "𝞀",
    "mbfsansvarsigma": "𝞁",
    "mbfsanssigma": "𝞂",
    "mbfsanstau": "𝞃",
    "mbfsansupsilon": "𝞄",
    "mbfsansvarphi": "𝞅",
    "mbfsanschi": "𝞆",
    "mbfsanspsi": "𝞇",
    "mbfsansomega": "𝞈",
    "mbfsanspartial": "𝞉",
    "mbfsansepsilon": "𝞊",
    "mbfsansvartheta": "𝞋",
    "mbfsansvarkappa": "𝞌",
    "mbfsansphi": "𝞍",
    "mbfsansvarrho": "𝞎",
    "mbfsansvarpi": "𝞏",
    "mbfitsansAlpha": "𝞐",
    "mbfitsansBeta": "𝞑",
    "mbfitsansGamma": "𝞒",
    "mbfitsansDelta": "𝞓",
    "mbfitsansEpsilon": "𝞔",
    "mbfitsansZeta": "𝞕",
    "mbfitsansEta": "𝞖",
    "mbfitsansTheta": "𝞗",
    "mbfitsansIota": "𝞘",
    "mbfitsansKappa": "𝞙",
    "mbfitsansLambda": "𝞚",
    "mbfitsansMu": "𝞛",
    "mbfitsansNu": "𝞜",
    "mbfitsansXi": "𝞝",
    "mbfitsansOmicron": "𝞞",
    "mbfitsansPi": "𝞟",
    "mbfitsansRho": "𝞠",
    "mbfitsansvarTheta": "𝞡",
    "mbfitsansSigma": "𝞢",
    "mbfitsansTau": "𝞣",
    "mbfitsansUpsilon": "𝞤",
    "mbfitsansPhi": "𝞥",
    "mbfitsansChi": "𝞦",
    "mbfitsansPsi": "𝞧",
    "mbfitsansOmega": "𝞨",
    "mbfitsansnabla": "𝞩",
    "mbfitsansalpha": "𝞪",
    "mbfitsansbeta": "𝞫",
    "mbfitsansgamma": "𝞬",
    "mbfitsansdelta": "𝞭",
    "mbfitsansvarepsilon": "𝞮",
    "mbfitsanszeta": "𝞯",
    "mbfitsanseta": "𝞰",
    "mbfitsanstheta": "𝞱",
    "mbfitsansiota": "𝞲",
    "mbfitsanskappa": "𝞳",
    "mbfitsanslambda": "𝞴",
    "mbfitsansmu": "𝞵",
    "mbfitsansnu": "𝞶",
    "mbfitsansxi": "𝞷",
    "mbfitsansomicron": "𝞸",
    "mbfitsanspi": "𝞹",
    "mbfitsansrho": "𝞺",
    "mbfitsansvarsigma": "𝞻",
    "mbfitsanssigma": "𝞼",
    "mbfitsanstau": "𝞽",
    "mbfitsansupsilon": "𝞾",
    "mbfitsansvarphi": "𝞿",
    "mbfitsanschi": "𝟀",
    "mbfitsanspsi": "𝟁",
    "mbfitsansomega": "𝟂",
    "mbfitsanspartial": "𝟃",
    "mbfitsansepsilon": "𝟄",
    "mbfitsansvartheta": "𝟅",
    "mbfitsansvarkappa": "𝟆",
    "mbfitsansphi": "𝟇",
    "mbfitsansvarrho": "𝟈",
    "mbfitsansvarpi": "𝟉",
    "mbfDigamma": "𝟊",
    "mbfdigamma": "𝟋",
    "mbfzero": "𝟎",
    "mbfone": "𝟏",
    "mbftwo": "𝟐",
    "mbfthree": "𝟑",
    "mbffour": "𝟒",
    "mbffive": "𝟓",
    "mbfsix": "𝟔",
    "mbfseven": "𝟕",
    "mbfeight": "𝟖",
    "mbfnine": "𝟗",
    "Bbbzero": "𝟘",
    "Bbbone": "𝟙",
    "Bbbtwo": "𝟚",
    "Bbbthree": "𝟛",
    "Bbbfour": "𝟜",
    "Bbbfive": "𝟝",
    "Bbbsix": "𝟞",
    "Bbbseven": "𝟟",
    "Bbbeight": "𝟠",
    "Bbbnine": "𝟡",
    "msanszero": "𝟢",
    "msansone": "𝟣",
    "msanstwo": "𝟤",
    "msansthree": "𝟥",
    "msansfour": "𝟦",
    "msansfive": "𝟧",
    "msanssix": "𝟨",
    "msansseven": "𝟩",
    "msanseight": "𝟪",
    "msansnine": "𝟫",
    "mbfsanszero": "𝟬",
    "mbfsansone": "𝟭",
    "mbfsanstwo": "𝟮",
    "mbfsansthree": "𝟯",
    "mbfsansfour": "𝟰",
    "mbfsansfive": "𝟱",
    "mbfsanssix": "𝟲",
    "mbfsansseven": "𝟳",
    "mbfsanseight": "𝟴",
    "mbfsansnine": "𝟵",
    "mttzero": "𝟶",
    "mttone": "𝟷",
    "mtttwo": "𝟸",
    "mttthree": "𝟹",
    "mttfour": "𝟺",
    "mttfive": "𝟻",
    "mttsix": "𝟼",
    "mttseven": "𝟽",
    "mtteight": "𝟾",
    "mttnine": "𝟿",
    "arabicmaj": "𞻰",
    "arabichad": "𞻱",
    "Alpha": "Α",
    "Beta": "Β",
    "Gamma": "Γ",
    "Delta": "Δ",
    "Epsilon": "Ε",
    "Zeta": "Ζ",
    "Eta": "Η",
    "Theta": "Θ",
    "Iota": "Ι",
    "Kappa": "Κ",
    "Lambda": "Λ",
    "Mu": "Μ",
    "Nu": "Ν",
    "Xi": "Ξ",
    "Omicron": "Ο",
    "Pi": "Π",
    "Rho": "Ρ",
    "Sigma": "Σ",
    "Tau": "Τ",
    "Upsilon": "Υ",
    "Phi": "Φ",
    "Chi": "Χ",
    "Psi": "Ψ",
    "Omega": "Ω",
    "alpha": "α",
    "beta": "β",
    "gamma": "γ",
    "delta": "δ",
    "epsilon": "ϵ",
    "zeta": "ζ",
    "eta": "η",
    "theta": "θ",
    "iota": "ι",
    "kappa": "κ",
    "lambda": "λ",
    "mu": "μ",
    "nu": "ν",
    "xi": "ξ",
    "omicron": "ο",
    "pi": "π",
    "rho": "ρ",
    "sigma": "σ",
    "tau": "τ",
    "upsilon": "υ",
    "phi": "ϕ",
    "chi": "χ",
    "psi": "ψ",
    "omega": "ω",
    "varepsilon": "ε",
    "vartheta": "ϑ",
    "varkappa": "ϰ",
    "varpi": "ϖ",
    "varrho": "ϱ",
    "varsigma": "ς",
    "varphi": "φ",
    "iff": "⟺",
    "coda": "𝄌",
    "segno": "𝄋",
    "Complex": "ℂ",
    "N": "ℕ",
    "Q": "ℚ",
    "R": "ℝ",
    "Z": "ℤ",
    "thickmuskip": "  ",
    "medmuskip": " ",
    "thinmuskip": " ",
    "trademark": "™",
    "square": "□",
    "rhd": "▷",
    "centerdot": "⋅",
    "circledS": "Ⓢ",
    "copyright": "©",
    "cents": "¢",
    "triangle": "△",
    "textregistered": "®",
    "bigcirc": "○",
    "unlhd": "⊴",
    "unrhd": "⊵",
    "thickapprox": "≈",
    "pound": "£",
    "doteqdot": "≑",
    "smallfrown": "⌢",
    "digamma": "Ϝ",
    "shortparallel": "∥",
    "leadsto": "⤳",
    "pilcrow": "¶",
    "smallsmile": "⌣",
    "space": "␣",
    "ge": "≥",
    "texttrademark": "™",
    "hbar": "ℏ",
    "section": "§",
    "le": "≤",
    "varpropto": "∝",
    "Box": "□",
    "lhd": "◁",
    "registered": "®",
    "thicksim": "∼",
    "implies": "⇒",
    "blacksquare": "⬛",
    "blacklozenge": "⧫",
    "degree": "°",
    "{": "{",
    "}": "}",
    "sptilde": "~",
    "cent": "¢",
    "pounds": "£",
    "yen": "¥",
    "spddot": "¨",
    "lnot": "¬",
    "circledR": "®",
    "Micro": "µ",
    "eth": "ð",
    "upMu": "Μ",
    "upNu": "Ν",
    "upOmicron": "Ο",
    "upepsilon": "ε",
    "upomicron": "ο",
    "upvarbeta": "ϐ",
    "upoldKoppa": "Ϙ",
    "upoldkoppa": "ϙ",
    "Stigma": "Ϛ",
    "upstigma": "ϛ",
    "Koppa": "Ϟ",
    "upkoppa": "ϟ",
    "Sampi": "Ϡ",
    "upsampi": "ϡ",
    "textTheta": "ϴ",
    "backepsilon": "϶",
    "quad": " ",
    "|": "‖",
    "ldots": "…",
    "second": "″",
    "third": "‴",
    "cat": "⁀",
    "fourth": "⁗",
    "lvec": "⃖",
    "LVec": "⃖",
    "Euler": "ℇ",
    "tcohm": "Ω",
    "Angstroem": "Å",
    "CapitalDifferentialD": "ⅅ",
    "DifferentialD": "ⅆ",
    "ExponetialE": "ⅇ",
    "ComplexI": "ⅈ",
    "ComplexJ": "ⅉ",
    "invamp": "⅋",
    "to": "→",
    "MapsUp": "↥",
    "MapsDown": "↧",
    "lightning": "↯",
    "dlsh": "↲",
    "drsh": "↳",
    "barleftarrowrightarrowba": "↹",
    "circlearrowleft": "↺",
    "circlearrowright": "↻",
    "dashleftarrow": "⇠",
    "dashrightarrow": "⇢",
    "LeftArrowBar": "⇤",
    "RightArrowBar": "⇥",
    "mathord": "⍹",
    "pfun": "⇸",
    "ffun": "⇻",
    "emptyset": "∅",
    "slash": "∕",
    "circ": "∘",
    "bullet": "∙",
    "sqrt[3]": "∛",
    "sqrt[4]": "∜",
    "land": "∧",
    "lor": "∨",
    "Proportion": "∷",
    "AC": "∿",
    "corresponds": "≙",
    "neq": "≠",
    "not\\eq": "≠",
    "notasymp": "≭",
    "NotLessTilde": "≴",
    "NotGreaterTilde": "≵",
    "NotGreaterLess": "≹",
    "multimapdotbothA": "⊶",
    "multimapdotbothB": "⊷",
    "diamond": "⋄",
    "hash": "⋕",
    "npreceq": "⋠",
    "nsucceq": "⋡",
    "ntriangleleft": "⋪",
    "ntriangleright": "⋫",
    "cdots": "⋯",
    "iddots": "⋰",
    "barin": "⋶",
    "invneg": "⌐",
    "wasylozenge": "⌑",
    "APLinv": "⌹",
    "notslash": "⌿",
    "notbackslash": "⍀",
    "APLleftarrowbox": "⍇",
    "APLrightarrowbox": "⍈",
    "APLuparrowbox": "⍐",
    "APLdownarrowbox": "⍗",
    "APLcomment": "⍝",
    "APLinput": "⍞",
    "APLlog": "⍟",
    "blacktriangleup": "▴",
    "smalltriangleup": "▵",
    "RHD": "▶",
    "smalltriangledown": "▿",
    "LHD": "◀",
    "Diamondblack": "◆",
    "Diamond": "◇",
    "lozenge": "◊",
    "Circle": "○",
    "CIRCLE": "●",
    "LEFTcircle": "◐",
    "RIGHTcircle": "◑",
    "LEFTCIRCLE": "◖",
    "RIGHTCIRCLE": "◗",
    "Sun": "☉",
    "Square": "☐",
    "CheckedBox": "☑",
    "XBox": "☒",
    "steaming": "☕",
    "pointright": "☞",
    "skull": "☠",
    "radiation": "☢",
    "biohazard": "☣",
    "yinyang": "☯",
    "frownie": "☹",
    "smiley": "☺",
    "mercury": "☿",
    "earth": "♁",
    "jupiter": "♃",
    "saturn": "♄",
    "uranus": "♅",
    "neptune": "♆",
    "pluto": "♇",
    "aries": "♈",
    "taurus": "♉",
    "gemini": "♊",
    "cancer": "♋",
    "leo": "♌",
    "virgo": "♍",
    "libra": "♎",
    "scorpio": "♏",
    "sagittarius": "♐",
    "capricornus": "♑",
    "aquarius": "♒",
    "pisces": "♓",
    "sixteenthnote": "♬",
    "recycle": "♻",
    "anchor": "⚓",
    "swords": "⚔",
    "warning": "⚠",
    "medcirc": "⚪",
    "medbullet": "⚫",
    "pencil": "✎",
    "ballotx": "✗",
    "arrowbullet": "➢",
    "Lbag": "⟅",
    "Rbag": "⟆",
    "Diamonddot": "⟐",
    "llbracket": "⟦",
    "rrbracket": "⟧",
    "lang": "⟪",
    "rang": "⟫",
    "psur": "⤀",
    "dbkarow": "⤏",
    "drbkarow": "⤐",
    "UpArrowBar": "⤒",
    "DownArrowBar": "⤓",
    "pinj": "⤔",
    "finj": "⤕",
    "bij": "⤖",
    "hksearow": "⤥",
    "hkswarow": "⤦",
    "leftrightharpoon": "⥊",
    "rightleftharpoon": "⥋",
    "leftrightharpoonup": "⥎",
    "rightupdownharpoon": "⥏",
    "leftrightharpoondown": "⥐",
    "leftupdownharpoon": "⥑",
    "LeftVectorBar": "⥒",
    "RightVectorBar": "⥓",
    "RightUpVectorBar": "⥔",
    "RightDownVectorBar": "⥕",
    "DownLeftVectorBar": "⥖",
    "DownRightVectorBar": "⥗",
    "LeftUpVectorBar": "⥘",
    "LeftDownVectorBar": "⥙",
    "LeftTeeVector": "⥚",
    "RightTeeVector": "⥛",
    "RightUpTeeVector": "⥜",
    "RightDownTeeVector": "⥝",
    "DownLeftTeeVector": "⥞",
    "DownRightTeeVector": "⥟",
    "LeftUpTeeVector": "⥠",
    "LeftDownTeeVector": "⥡",
    "leftleftharpoons": "⥢",
    "upupharpoons": "⥣",
    "rightrightharpoons": "⥤",
    "downdownharpoons": "⥥",
    "leftbarharpoon": "⥪",
    "barleftharpoon": "⥫",
    "rightbarharpoon": "⥬",
    "barrightharpoon": "⥭",
    "updownharpoons": "⥮",
    "downupharpoons": "⥯",
    "strictfi": "⥼",
    "strictif": "⥽",
    "VERT": "⦀",
    "spot": "⦁",
    "Lparen": "⦅",
    "Rparen": "⦆",
    "limg": "⦇",
    "rimg": "⦈",
    "lblot": "⦉",
    "rblot": "⦊",
    "circledbslash": "⦸",
    "circledless": "⧀",
    "circledgtr": "⧁",
    "boxslash": "⧄",
    "LeftTriangleBar": "⧏",
    "RightTriangleBar": "⧐",
    "multimapboth": "⧟",
    "zhide": "⧹",
    "varprod": "⨉",
    "Coloneqq": "⩴",
    "Equal": "⩵",
    "Same": "⩶",
    "NestedLessLess": "⪡",
    "NestedGreaterGreater": "⪢",
    "leftslice": "⪦",
    "rightslice": "⪧",
    "llcurly": "⪻",
    "ggcurly": "⪼",
    "Top": "⫪",
    "Bot": "⫫",
}
